@@ -43,6 +43,7 @@ class ImageAnnotations(BaseExtension):
     """
     
     preferences_ui = 'extensions.ImageAnnotations.preferences'
+    re_strip_ansi_codes = re.compile(chr(27) + r'\[[0-9;]+m')
     
     def event_startup(self):
         """Creates a folder for the image files if it doesn't exist, and
@@ -177,6 +178,31 @@ class ImageAnnotations(BaseExtension):
             )
         self._set_annotations(editor, mode)
         
+    def event_image_annotations_clear_output(self):
+        
+        editor = self.extension_manager.provide('ide_current_editor')
+        if editor is None:
+            return
+        code = editor.toPlainText()
+        cells = self.extension_manager.provide(
+            'jupyter_notebook_cells',
+            code=code,
+            cell_types=['code']
+        )
+        for cell in cells:
+            if not 'outputs' in cell:
+                continue
+            code = code.replace(
+                '{}\n{}'.format(OUTPUT_MARKER, cell['outputs']),
+                ''
+            )
+        # We use a cursor rather than simply setting the text, so that this
+        # action can be undone.
+        cursor = editor.textCursor()
+        cursor.select(cursor.Document)
+        cursor.insertText(code)
+        editor.setTextCursor(cursor)
+        
     def event_ide_save_current_file_as(self, from_path, to_path):
         
         if from_path not in self._image_annotations:
@@ -230,6 +256,15 @@ class ImageAnnotations(BaseExtension):
         """
         self._capturing = False
         
+    def _format_output(self, text):
+        """Formats a block of output so that ansi color codes are removed and
+        that each lines is quoted.
+        """
+        return '\n'.join([
+            '# {}'.format(self.re_strip_ansi_codes.sub(' ', line))
+            for line in text.splitlines()
+        ])
+        
     def event_jupyter_execute_result_text(self, text):
         """Gets text that is sent to the Jupyter console and captures it if
         capturing is enabled.
@@ -249,9 +284,7 @@ class ImageAnnotations(BaseExtension):
                 )
             )
         self._has_captured = True
-        formatted_output = '\n'.join(
-            ['# {}'.format(line) for line in text.splitlines()]
-        )
+        formatted_output = self._format_output(text)
         if not formatted_output:
             return
         self._text_operation(
